pub struct BleConnector<'d> { /* private fields */ }ble and unstable only.Expand description
A blocking HCI connector
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'d> BleConnector<'d>
impl<'d> BleConnector<'d>
Sourcepub fn new(
device: BT<'d>,
config: Config,
) -> Result<BleConnector<'d>, BleInitError>
pub fn new( device: BT<'d>, config: Config, ) -> Result<BleConnector<'d>, BleInitError>
Create and init a new BLE connector.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn next(&mut self, buf: &mut [u8]) -> Result<usize, BleConnectorError>
pub fn next(&mut self, buf: &mut [u8]) -> Result<usize, BleConnectorError>
Read the next HCI packet from the BLE controller.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn read(&mut self, buf: &mut [u8]) -> Result<usize, BleConnectorError>
pub fn read(&mut self, buf: &mut [u8]) -> Result<usize, BleConnectorError>
Read from HCI.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub async fn read_async(
&mut self,
buf: &mut [u8],
) -> Result<usize, BleConnectorError>
pub async fn read_async( &mut self, buf: &mut [u8], ) -> Result<usize, BleConnectorError>
Read from HCI.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn write(&mut self, buf: &[u8]) -> Result<usize, BleConnectorError>
pub fn write(&mut self, buf: &[u8]) -> Result<usize, BleConnectorError>
Write to HCI.
Returns the number of bytes written, which is at most one packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub async fn write_async(
&mut self,
buf: &[u8],
) -> Result<usize, BleConnectorError>
pub async fn write_async( &mut self, buf: &[u8], ) -> Result<usize, BleConnectorError>
Write to HCI asynchronously.
Returns the number of bytes written, which is at most one packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.